pygeodesy.geodesicx.gxarea.PolygonArea

Package pygeodesy :: Package geodesicx :: Module gxarea :: Class PolygonArea |
[frames] | no frames]

# Class PolygonArea

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
       GeodesicAreaExact --+
                           |
                          PolygonArea

For `geographiclib` compatibility, sub-class of GeodesicAreaExact.

Instance Methods
__init__(self, earth, polyline=False, **name) New PolygonArea instance. |
Inherited from `GeodesicAreaExact`: `AddEdge`, `AddPoint`, `Clear`, `Compute`, `Reset`, `TestEdge`, `TestPoint`, `toStr` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `GeodesicAreaExact`: `area0`, `area0x`, `earth`, `ellipsoid`, `geodesic`, `lat0`, `lat1`, `lon0`, `lon1`, `num`, `polyline`, `verbose` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, earth, polyline=False, **name) (Constructor) |
New PolygonArea instance. Arguments: `earth` - A geodesic (GeodesicExact, wrapped `Geodesic` or GeodesicSolve). `polyline` - If `True`, compute the perimeter only, otherwise perimeter and area (`bool`). `name` - Optional `name=NN` (`str`). Raises: `GeodesicError` - Invalid `earth`. Overrides: object.__init__